@@ -11,7 +11,7 @@
 //! - [Cookbook][_cookbook]
 //! - [FAQ][_faq]
 //! - [Discussions](https://github.com/clap-rs/clap/discussions)
-//! - [CHANGELOG](https://github.com/clap-rs/clap/blob/v4.5.3/CHANGELOG.md) (includes major version migration
+//! - [CHANGELOG](https://github.com/clap-rs/clap/blob/v4.5.6/CHANGELOG.md) (includes major version migration
 //!   guides)
 //!
 //! ## Aspirations
@@ -78,25 +78,12 @@
 //! - [Command-line Apps for Rust](https://rust-cli.github.io/book/index.html) book
 //!
 
-#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![doc(html_logo_url = "https://raw.githubusercontent.com/clap-rs/clap/master/assets/clap.png")]
-#![warn(
-    missing_docs,
-    missing_debug_implementations,
-    missing_copy_implementations,
-    trivial_casts,
-    unused_allocation,
-    trivial_numeric_casts,
-    clippy::single_char_pattern
-)]
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![forbid(unsafe_code)]
-// HACK https://github.com/rust-lang/rust-clippy/issues/7290
-#![allow(clippy::single_component_path_imports)]
-#![allow(clippy::branches_sharing_code)]
-// Doesn't allow for debug statements, etc to be unique
-#![allow(clippy::if_same_then_else)]
-// Breaks up parallelism that clarifies intent
-#![allow(clippy::collapsible_else_if)]
+#![warn(missing_docs)]
+#![warn(clippy::print_stderr)]
+#![warn(clippy::print_stdout)]
 
 pub use clap_builder::*;
 #[cfg(feature = "derive")]
